@@ -6,7 +6,7 @@
 
 package Lemonldap::NG::Manager::Build::Attributes;
 
-our $VERSION = '1.9.7';
+our $VERSION = '1.9.11';
 use strict;
 use Regexp::Common qw/URI/;
 
@@ -348,7 +348,6 @@ sub attributes {
 
         # Menu
         activeTimer => {
-            default       => 0,
             type          => 'bool',
             default       => 1,
             documentation => 'Enable timers on portal pages',
@@ -362,6 +361,17 @@ sub attributes {
             },
             documentation => 'Applications list',
         },
+        portalErrorOnExpiredSession => {
+            type          => 'bool',
+            default       => 1,
+            documentation => 'Show error if session is expired',
+        },
+        portalErrorOnMailNotFound => {
+            type    => 'bool',
+            default => 0,
+            documentation =>
+              'Show error if mail is not found in password reset process',
+        },
         portalOpenLinkInNewWindow => {
             type          => 'bool',
             default       => 0,
@@ -1694,6 +1704,7 @@ sub attributes {
                 { k => 'Facebook',      v => 'Facebook' },
                 { k => 'Google',        v => 'Google' },
                 { k => 'LDAP',          v => 'LDAP' },
+                { k => 'LinkedIn',      v => 'LinkedIn' },
                 { k => 'Multi',         v => 'Multiple' },
                 { k => 'Null',          v => 'None' },
                 { k => 'OpenID',        v => 'OpenID' },
@@ -2052,6 +2063,22 @@ m{^(?:ldapi://[^/]*/?|\w[\w\-\.]*(?::\d{1,5})?|ldap(?:s|\+tls)?://\w[\w\-\.]*(?:
         twitterSecret  => { type => 'text', },
         twitterAppName => { type => 'text', },
 
+        # LinkedIn
+        linkedInAuthnLevel => {
+            type          => 'int',
+            default       => 1,
+            documentation => 'LinkedIn authentication level',
+        },
+        linkedInClientID     => { type => 'text', },
+        linkedInClientSecret => { type => 'password', },
+        linkedInFields       => {
+            type    => 'text',
+            default => 'id,first-name,last-name,email-address'
+        },
+        linkedInUserField => { type => 'text', default => 'emailAddress' },
+        linkedInScope =>
+          { type => 'text', default => 'r_basicprofile r_emailaddress' },
+
         # WebID
         webIDAuthnLevel => {
             type          => 'int',
@@ -2089,6 +2116,14 @@ m{^(?:ldapi://[^/]*/?|\w[\w\-\.]*(?::\d{1,5})?|ldap(?:s|\+tls)?://\w[\w\-\.]*(?:
         userPivot          => { type => 'text', },
         dbiAuthPasswordHash =>
           { type => 'text', help => 'authdbi.html#password', },
+        dbiDynamicHashEnabled =>
+          { type => 'bool', help => 'authdbi.html#password', },
+        dbiDynamicHashValidSchemes =>
+          { type => 'text', help => 'authdbi.html#password', },
+        dbiDynamicHashValidSaltedSchemes =>
+          { type => 'text', help => 'authdbi.html#password', },
+        dbiDynamicHashNewPasswordScheme =>
+          { type => 'text', help => 'authdbi.html#password', },
         dbiExportedVars => {
             type          => 'keyTextContainer',
             keyTest       => qr/^!?[a-zA-Z][a-zA-Z0-9_-]*$/,
@@ -2159,6 +2194,7 @@ m{^(?:ldapi://[^/]*/?|\w[\w\-\.]*(?::\d{1,5})?|ldap(?:s|\+tls)?://\w[\w\-\.]*(?:
                     { k => 'Facebook',      v => 'Facebook' },
                     { k => 'Google',        v => 'Google' },
                     { k => 'LDAP',          v => 'LDAP' },
+                    { k => 'LinkedIn',      v => 'LinkedIn' },
                     { k => 'Null',          v => 'None' },
                     { k => 'OpenID',        v => 'OpenID' },
                     { k => 'OpenIDConnect', v => 'OpenID Connect' },
@@ -2436,6 +2472,7 @@ m{^(?:ldapi://[^/]*/?|\w[\w\-\.]*(?::\d{1,5})?|ldap(?:s|\+tls)?://\w[\w\-\.]*(?:
         oidcRPMetaDataOptionsExtraClaims =>
           { type => 'keyTextContainer', default => {} },
         oidcRPMetaDataOptionsBypassConsent => { type => 'bool', default => 0 },
+        oidcRPMetaDataOptionsPostLogoutRedirectUris => { type => 'text', },
 
     };
 }
